@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -321,6 +321,11 @@ class FromRattailToRattailExportConsumer(NewDataSyncImportConsumer):
         super(FromRattailToRattailExportConsumer, self).setup()
         self.topo_sortkey = make_topo_sortkey(self.model)
 
+        # TODO: this should default to True, once logic is proven
+        self.handle_price_xref = self.config.getbool(
+            'rattail.datasync', 'rattail.handle_price_xref',
+            default=False)
+
     def make_target_session(self):
         return Session(bind=self.target_engine)
 
@@ -335,16 +340,25 @@ class FromRattailToRattailExportConsumer(NewDataSyncImportConsumer):
             importer.host_session = session
             importer.session = target_session
 
-        # topographically sort changes, i.e. per schema table dependencies.
-        # we start with a lexical sort just for kicks maybe...
-        class_names = set([c.payload_type for c in changes])
-        class_names = sorted(class_names)
-        class_names.sort(key=self.topo_sortkey)
+        # note that we no longer sort changes here, since the watcher
+        # should have already done that...
+        for change in changes:
+            self.invoke_importer(session, change)
 
-        for class_name in class_names:
-            cls = getattr(self.model, class_name)
-            for change in [c for c in changes if c.payload_type == class_name]:
-                self.invoke_importer(session, change)
+        # if we had any Product changes, we may also want to process
+        # the "price uuid" fields for each, via a custom importer just
+        # for that purpose.  note that we do this *after* all other
+        # changes have been processed...in the hopes that ProductPrice
+        # records are already in place, and nothing will break!
+        if self.handle_price_xref:
+            product_changes = [c for c in changes
+                               if c.payload_type == 'Product' and not c.deletion]
+            if product_changes:
+                price_xref_importer = self.handler.get_importer(
+                    'ProductPriceAssociation',
+                    host_session=session, session=target_session)
+                for change in product_changes:
+                    self.process_change(session, price_xref_importer, change)
 
         target_session.commit()
         target_session.close()
