@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -178,6 +178,7 @@ class ImporterEmail(Email):
         return {
             'host_title': handler.host_title,
             'local_title': handler.local_title,
+            'direction': 'import',
             'runtime': "1 second",
             'argv': ['bin/rattail', 'import-something'],
             'changes': {
@@ -256,6 +257,7 @@ class user_feedback(Email):
 
     def sample_data(self, request):
         return {
+            'app_title': request.rattail_config.app_title(default="Rattail"),
             'user': None,
             'user_name': "Fred Flintstone",
             'referrer': request.route_url('home'),
