@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -59,6 +59,18 @@ class Importer(object):
        Note that the handler is responsible for assigning this value; the
        importer should not define it.  See also
        :attr:`rattail.importing.handlers.ImportHandler.direction`.
+
+    :attr collect_changes_for_processing:
+
+       If true (the default) then any changes occurring as a result of the
+       import will be collected for processing by the handler, once the import
+       has completed.  (I.e. it might send out a warning email with the
+       changes.)  If the changes are not "important" per se, and they involve
+       large data sets, then you may want to turn off this flag to avoid the
+       overhead of collecting the changes.  In practice this is usually done if
+       memory consumption is too great, as long as you don't actually need to
+       track the changes.  Also note that the flag usually may be turned off 
+       via command line kwarg (``--no-collect-changes``).
     """
     # Set this to the data model class which is targeted on the local side.
     model_class = None
@@ -96,6 +108,8 @@ class Importer(object):
     host_system_title = None
     local_system_title = None
 
+    collect_changes_for_processing = True
+
     # TODO
     # Whether or not the registered "importer" batch handler is able to handle
     # batches for this importer (and/or, whether this importer is able to
@@ -235,15 +249,20 @@ class Importer(object):
 
         # Create and/or update data.
         if self.create or self.update:
-            created, updated = self._import_create_update(host_data)
+            if self.collect_changes_for_processing:
+                created, updated = self._import_create_update(host_data)
+            else:
+                self._import_create_update(host_data)
 
         # Delete data.
         if self.delete:
             changes = len(created) + len(updated)
             if self.max_total and changes >= self.max_total:
                 log.warning("max of {} total changes already reached; skipping deletions".format(self.max_total))
-            else:
+            elif self.collect_changes_for_processing:
                 deleted = self._import_delete(host_data, set(unique), changes=changes)
+            else:
+                self._import_delete(host_data, set(unique), changes=changes)
 
         self.teardown()
         return created, updated, deleted
@@ -259,6 +278,7 @@ class Importer(object):
         count = len(data)
         if not count:
             return created, updated
+        dummy = object()
 
         def import_(host_data, i):
             
@@ -274,7 +294,10 @@ class Importer(object):
                     log.debug("fields '{}' differed for local data: {}, host data: {}".format(
                         ','.join(diffs), local_data, host_data))
                     local_object = self.update_object(local_object, host_data, local_data=local_data)
-                    updated.append((local_object, local_data, host_data))
+                    if self.collect_changes_for_processing:
+                        updated.append((local_object, local_data, host_data))
+                    else:
+                        updated.append(dummy)
                     if self.max_update and len(updated) >= self.max_update:
                         log.warning("max of {} *updated* records has been reached; stopping now".format(self.max_update))
                         raise ImportLimitReached()
@@ -287,7 +310,10 @@ class Importer(object):
                 local_object = self.create_object(key, host_data)
                 if local_object:
                     log.debug("created new {} {}: {}".format(self.model_name, key, local_object))
-                    created.append((local_object, host_data))
+                    if self.collect_changes_for_processing:
+                        created.append((local_object, host_data))
+                    else:
+                        created.append(dummy)
                     if self.caches_local_data and self.cached_local_data is not None:
                         self.cached_local_data[key] = {'object': local_object, 'data': self.normalize_local_object(local_object)}
                     if self.max_create and len(created) >= self.max_create:
@@ -399,12 +425,16 @@ class Importer(object):
         deleting = self.get_deletion_keys() - host_keys
         count = len(deleting)
         log.debug("found {} instances to delete".format(count))
+        dummy = object()
 
         def delete(key, i):
             cached = self.cached_local_data.pop(key)
             obj = cached['object']
             if self.delete_object(obj):
-                deleted.append((obj, cached['data']))
+                if self.collect_changes_for_processing:
+                    deleted.append((obj, cached['data']))
+                else:
+                    deleted.append(dummy)
                 if self.max_delete and len(deleted) >= self.max_delete:
                     log.warning("max of {} *deleted* records has been reached; stopping now".format(self.max_delete))
                     raise ImportLimitReached()
@@ -735,7 +765,11 @@ class BatchImporter(Importer):
         while host_data:
             if self.caches_local_data:
                 self.cached_local_data = self.cache_local_data(host_data)
-            created, updated = self._import_create_update(host_data, created=created, updated=updated)
+
+            if self.collect_changes_for_processing:
+                created, updated = self._import_create_update(host_data, created=created, updated=updated)
+            else:
+                self._import_create_update(host_data)
 
             if self.max_create and len(created) >= self.max_create:
                 log.warning("max of {} *created* records has been reached; stopping now".format(self.max_create))
@@ -751,6 +785,7 @@ class BatchImporter(Importer):
             host_data = self.normalize_host_data()
 
         self.teardown()
+        # note that these may not be accurate, if we didn't collect changes above
         return created, updated, deleted
 
     def cache_local_data(self, host_data=None):
