@@ -132,7 +132,8 @@ class ToSQLAlchemy(Importer):
                                 query=self.cache_query(),
                                 # omit_duplicates=True,
                                 query_options=self.cache_query_options(),
-                                normalizer=self.normalize_cache_object)
+                                normalizer=self.normalize_cache_object,
+                                message=self.cache_local_message())
 
     def cache_query(self):
         """
@@ -152,3 +153,43 @@ class ToSQLAlchemy(Importer):
         made thus far.
         """
         self.session.flush()
+
+
+class FromSQLAlchemySameToSame(FromSQLAlchemy):
+    """
+    Special base class for importers which sync data from one database to
+    another, when the schema for each database is identical.
+    """
+
+    @property
+    def host_model_class(self):
+        return self.model_class
+
+    @property
+    def supported_fields(self):
+        """
+        We only need to support the simple fields, since all relevant tables
+        should be covered and therefore no need to do crazy foreign key
+        acrobatics etc.
+        """
+        return self.simple_fields
+
+    def query(self):
+        """
+        Leverage the same caching optimizations on both sides, if applicable.
+        """
+        query = super(FromSQLAlchemySameToSame, self).query()
+
+        if hasattr(self, 'cache_query_options'):
+            options = self.cache_query_options()
+            if options:
+                for option in options:
+                    query = query.options(option)
+
+        return query
+
+    def normalize_host_object(self, obj):
+        """
+        Normalization should work the same for both sides.
+        """
+        return self.normalize_local_object(obj)
